=======
pynetcf
=======

.. image:: https://travis-ci.org/TUW-GEO/pynetCF.svg?branch=master
    :target: https://travis-ci.org/TUW-GEO/pynetCF

.. image:: https://coveralls.io/repos/github/TUW-GEO/pynetCF/badge.svg?branch=master
   :target: https://coveralls.io/github/TUW-GEO/pynetCF?branch=master

.. image:: https://badge.fury.io/py/pynetCF.svg
    :target: http://badge.fury.io/py/pynetCF


Description
===========

Basic python classes that map to netCDF files on disk written according to the [Climate and Forecast metadata conventions](http://cfconventions.org/Data/cf-conventions/cf-conventions-1.6/build/cf-conventions.html) 

This is a first draft which has a lot of room for improvements, this is especially true for the time series based representations.


Documentation
=============

|Documentation Status|

.. |Documentation Status| image:: https://readthedocs.org/projects/pynetCF/badge/?version=latest
   :target: http://pynetCF.readthedocs.org/


How to use
==========

For now please see the tests for examples on how to use the classes.
